@@ -4,23 +4,34 @@
 /* structure to represent the configuration of the volume manager */
 struct gvm_configuration {
 	GConfClient *client;
-
+	
 	gboolean automount_drives;
 	gboolean automount_media;
+	gboolean autobrowse;
 	gboolean autorun;
-	gchar *autorun_path;
-
-	gboolean autoburn_cdr;
-	gchar *autoburn_cdr_command;	
-
+	char *autorun_path;
+	
+	gboolean autoburn;
+	char *autoburn_audio_cd_command;
+	char *autoburn_photo_cd_command;
+	char *autoburn_data_cd_command;
+	
 	gboolean autoplay_cda;
-	gchar *autoplay_cda_command;
-
+	char *autoplay_cda_command;
+	
 	gboolean autoplay_dvd;
-	gchar *autoplay_dvd_command;
-
+	char *autoplay_dvd_command;
+	
 	gboolean autophoto;
-	gchar *autophoto_command;
+	char *autophoto_command;
+	
+	gboolean autoipod;
+	char *autoipod_command;
+	
+	gboolean autoprinter;
+	char *autoprinter_command;
+	
+	char *eject_command;
 };
 
 /* where our settings are rooted in the gconf tree */
